@@ -1019,13 +1019,15 @@ handle_mount_unmount (GVfsRemoteVolumeMonitor *object,
   for (l = mounts; l != NULL; l = l->next)
     {
       char *mount_id;
+      gboolean same;
 
       mount = G_MOUNT (l->data);
       mount_id = g_strdup_printf ("%p", mount);
-      if (strcmp (mount_id, arg_id) == 0)
-        break;
-
+      same = strcmp (mount_id, arg_id) == 0;
       g_free (mount_id);
+
+      if (same)
+        break;
     }
   if (l == NULL)
     mount = NULL;
@@ -1256,13 +1258,15 @@ handle_volume_mount (GVfsRemoteVolumeMonitor *object,
   for (l = volumes; l != NULL; l = l->next)
     {
       char *volume_id;
+      gboolean same;
 
       volume = G_VOLUME (l->data);
       volume_id = g_strdup_printf ("%p", volume);
-      if (strcmp (volume_id, arg_id) == 0)
-        break;
-
+      same = strcmp (volume_id, arg_id) == 0;
       g_free (volume_id);
+
+      if (same)
+        break;
     }
   if (l == NULL)
     volume = NULL;
